'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

exports.validation = validation;

var _formFieldHelpers = require('./validationHelpers/formFieldHelpers');

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _ui = require('@modul/ui');

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/**
 * HOC для обертки над инпутами, чтобы получить необходимые методы подсветки ошибок и т.д.
 * getTooltipError - текст ошибки для тултипа
 * isError - флаг ошибки
 * isSuccess - флаг валидности поля
 * addClassName - css класс success|error
 * tooltip: tooltip - конфиг для тултипа, который внедреятся в <input/>
 *
 * tips - включены ли подскажи тултипа
 */
function validation() {
    var _ref = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : { tips: true, hideOnClickOutside: true },
        tips = _ref.tips,
        hideOnClickOutside = _ref.hideOnClickOutside;

    return function (WrappedComponent) {
        var radValidateTooltip = function (_React$Component) {
            _inherits(radValidateTooltip, _React$Component);

            function radValidateTooltip(props, context) {
                _classCallCheck(this, radValidateTooltip);

                var _this = _possibleConstructorReturn(this, (radValidateTooltip.__proto__ || Object.getPrototypeOf(radValidateTooltip)).call(this, props, context));

                _this.state = {
                    manuallyShowTooltip: false
                };

                _this.validatorId = (0, _formFieldHelpers.getRandomKey)();
                _this.tooltipId = 'tooltip_' + _this.validatorId;
                return _this;
            }

            _createClass(radValidateTooltip, [{
                key: 'componentDidUpdate',
                value: function componentDidUpdate(prevProps) {
                    var _this2 = this;

                    var _props$meta = this.props.meta,
                        submitFailed = _props$meta.submitFailed,
                        active = _props$meta.active,
                        error = _props$meta.error;
                    var wasActive = prevProps.meta.active;


                    if (submitFailed && error && !wasActive && active) {
                        setTimeout(function () {
                            if (_this2.wrappedEl) {
                                if (!_this2.wrappedEl.focusator) return;
                                _this2.wrappedEl.focusator.setFocus();
                            }
                        }, 0);
                    }
                }
            }, {
                key: 'inFocus',
                value: function inFocus() {
                    var active = this.props.meta.active;

                    return active || this.wrappedEl && this.wrappedEl.inFocus && this.wrappedEl.inFocus();
                }
            }, {
                key: 'getError',
                value: function getError() {
                    var error = this.props.meta.error;

                    return error && (error.text || error);
                }
            }, {
                key: 'showTooltipError',
                value: function showTooltipError(_ref2) {
                    var active = _ref2.active,
                        touched = _ref2.touched,
                        error = _ref2.error,
                        submitFailed = _ref2.submitFailed,
                        showErrorOnTouch = _ref2.showErrorOnTouch;

                    return error && (submitFailed || touched) && (active || showErrorOnTouch);
                }
            }, {
                key: 'setManuallyShowTooltip',
                value: function setManuallyShowTooltip(manuallyShowTooltip) {
                    this.setState({ manuallyShowTooltip: manuallyShowTooltip });
                }
            }, {
                key: 'getTooltipProps',
                value: function getTooltipProps(tipPlace) {
                    var self = this;
                    return {
                        placement: tipPlace || "top",
                        preventHideOnFocus: false,
                        getContent: self.getError.bind(self),
                        className: "error",
                        trigger: "manual",
                        showInitial: true,
                        hideOnClickOutside: hideOnClickOutside,
                        html: true
                    };
                }
            }, {
                key: 'getHintTooltipProps',
                value: function getHintTooltipProps(tipPlace) {
                    var self = this;
                    return {
                        placement: tipPlace || "top",
                        preventHideOnFocus: false,
                        getContent: self.getError.bind(self),
                        className: "",
                        trigger: "manual",
                        showInitial: true,
                        hideOnClickOutside: true,
                        html: true
                    };
                }
            }, {
                key: 'getTooltipConfig',
                value: function getTooltipConfig(_ref3) {
                    var id = _ref3.id;

                    return {
                        'data-mtip': id
                    };
                }
            }, {
                key: 'render',
                value: function render() {
                    var _this3 = this;

                    var _props = this.props,
                        _props$meta2 = _props.meta,
                        touched = _props$meta2.touched,
                        error = _props$meta2.error,
                        active = _props$meta2.active,
                        valid = _props$meta2.valid,
                        visited = _props$meta2.visited,
                        submitFailed = _props$meta2.submitFailed,
                        hideTips = _props.hideTips,
                        showErrorOnTouch = _props.showErrorOnTouch;
                    /* ручная инициация посещения поля */

                    touched = touched || this.state.manuallyShowTooltip;
                    active = active || this.state.manuallyShowTooltip;

                    var _props2 = this.props,
                        tipPlace = _props2.tipPlace,
                        wrappedProps = _objectWithoutProperties(_props2, ['tipPlace']);

                    var tooltip = this.getTooltipConfig({ id: this.tooltipId });

                    var isError = (0, _formFieldHelpers.showErrorBorder)({ valid: valid, error: error, touched: touched, submitFailed: submitFailed });
                    var isSuccess = (0, _formFieldHelpers.showSuccessBorder)({ valid: valid, visited: visited, error: error, active: active });

                    var additionalClassName = (0, _classnames2.default)({ error: isError }, { success: isSuccess });

                    var validator = {
                        error: error,
                        isError: isError,
                        isSuccess: isSuccess,
                        addClassName: additionalClassName,
                        tooltip: tooltip
                    };

                    if (tips && !hideTips) {
                        var showErrorMessage = this.showTooltipError({ active: active, touched: touched, error: error, submitFailed: submitFailed, showErrorOnTouch: showErrorOnTouch });
                        var tooltipProps = this.getTooltipProps(tipPlace);

                        return _react2.default.createElement(
                            _react2.default.Fragment,
                            null,
                            _react2.default.createElement(WrappedComponent, _extends({ ref: function ref(wrappedEl) {
                                    return _this3.wrappedEl = wrappedEl;
                                }
                            }, wrappedProps, { validator: validator })),
                            showErrorMessage && _react2.default.createElement(_ui.ModulTooltip, _extends({ dataFor: this.tooltipId
                            }, tooltipProps))
                        );
                    }

                    return _react2.default.createElement(WrappedComponent, _extends({ ref: function ref(wrappedEl) {
                            return _this3.wrappedEl = wrappedEl;
                        }
                    }, wrappedProps, { validator: validator }));
                }
            }]);

            return radValidateTooltip;
        }(_react2.default.Component);

        return radValidateTooltip;
    };
}