'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
var EMAIL_REGEXP = /^[a-zA-Z0-9.!#$%&'*+\/=?^_`{|}~-]+@[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9-])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)+$/;
var EMAIL_REGEXP_WITH_LATIN = /^[a-zA-ZА-Яа-яЁё0-9.!#$%&'*+\\/=?^_`{|}~-]+@[a-zA-ZА-Яа-яЁё0-9](?:[a-zA-ZА-Яа-яЁё0-9-]{0,61}[a-zA-ZА-Яа-яЁё0-9-])?(?:\.[a-zA-ZА-Яа-яЁё0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-ZА-Яа-яЁё0-9])?)+$/;

var validEmail = exports.validEmail = function validEmail(email) {
	var withLatin = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;

	if ((email || '').length == 0) return true;

	var regExp = withLatin ? EMAIL_REGEXP_WITH_LATIN : EMAIL_REGEXP;
	return regExp.test(email);
};

var onlyCyr = exports.onlyCyr = function onlyCyr(string) {
	return (/^[а-яА-ЯёЁ\-\s]*$/.test(string)
	);
};

var firstSymbolCyr = exports.firstSymbolCyr = function firstSymbolCyr(str) {
	if (str && str.length >= 1) return (/^[а-яА-ЯёЁ]$/.test(str.charAt(0))
	);
	return true;
};

var validPassword = exports.validPassword = function validPassword(password) {
	return !isEmpty(password) && /^[A-Za-z0-9!"№%:;@#$%^&*(){}?_+=<>\~`§.\[\],\\\/|]+$/g.test(password); //должны быть буквы и цифры, заглавные и маленькие
};

var validPasswordLength = exports.validPasswordLength = function validPasswordLength(password) {
	return !isEmpty(password) && password.length >= 8;
};

var isEmpty = exports.isEmpty = function isEmpty(val) {
	return val === '' || val === null || val === undefined;
};

var isRequired = exports.isRequired = function isRequired(text) {
	return function (val) {
		return isEmpty(val) ? text : undefined;
	};
};

var isValidNumber = exports.isValidNumber = function isValidNumber(val) {
	if (isEmpty(val)) return true;
	return (/^(0(\.|,)\d+|[1-9]+[0-9]*((\.|,)\d+)?|0)$/.test(+val)
	);
};

// мин длинна
var validateMinLength = exports.validateMinLength = function validateMinLength(count, text) {
	return function (val) {
		return val.length < count ? text : undefined;
	};
};

var isZeroNumberFloat = exports.isZeroNumberFloat = function isZeroNumberFloat(val) {
	if (isEmpty(val)) return true;
	return (/^\d[0-9]*[.|,]{0,1}[0-9]+$/g.test(val)
	); // любые цифры с точкой или запятой в середине
};

var CELLPHONE_REGEXP = /^[0-9]{10}$/;
var getPlainNumber = exports.getPlainNumber = function getPlainNumber(value) {
	var tempNumber = value.replace ? value : value.toString();
	return tempNumber.replace(/[^0-9]+/g, '').substring(0, 10);
};

var isValidPhone = exports.isValidPhone = function isValidPhone(phone) {
	if (isEmpty(phone)) return true;
	phone = getPlainNumber(phone);
	if (phone.length <= 10) return CELLPHONE_REGEXP.test(phone);
	return false;
};

var validator = exports.validator = function validator(errorText, validateCondition) {
	return function () {
		return !validateCondition.apply(undefined, arguments) ? errorText : undefined;
	};
};

var getOnlyNumber = exports.getOnlyNumber = function getOnlyNumber(value, count) {
	var tempNumber = value.replace ? value : value.toString();
	return tempNumber.replace(/[^0-9]+/g, '').substring(0, count || 10);
};

// убирает пробелы вначале и в конце
var normilizeDelFirstEndSpace = exports.normilizeDelFirstEndSpace = function normilizeDelFirstEndSpace(val) {
	return val.replace(/(^\s*)|(\s*)$/g, '');
};

// латинские буквы, числа + не чувствителен к регистру
var validatorLatinNumber = exports.validatorLatinNumber = function validatorLatinNumber(value) {
	return (/^[а-яa-z0-9._-]+$/gi.test(value)
	);
};

// только латинские буквы, числа + не чувствителен к регистру
var validatorOnlyLatinNumber = exports.validatorOnlyLatinNumber = function validatorOnlyLatinNumber(value) {
	return (/^[a-z0-9]+$/gi.test(value)
	);
};

// normalize, только лат. буквы, цифры
var normalizeOnlyLatinNumber = exports.normalizeOnlyLatinNumber = function normalizeOnlyLatinNumber(value) {
	if (value.replace) {
		return value.replace(/[^a-z0-9]/gi, "");
	}
	return '';
};

// только латинские буквы, числа, спецсимволы + не чувствителен к регистру
var validatorOnlyLatinNumberSymb = exports.validatorOnlyLatinNumberSymb = function validatorOnlyLatinNumberSymb(value) {
	return (/^([\/\-?:\"`'().,‘+a-z0-9 '])*$/gi.test(value)
	);
};

// normalize, не даёт ввести кириллицу, можно спец-символы
var normalizeOnlyLatinNumberSymb = exports.normalizeOnlyLatinNumberSymb = function normalizeOnlyLatinNumberSymb(value) {
	if (value.replace) {
		return value.replace(/[^/\-?:\"`'().,‘+a-z0-9 ']/gi, "");
	}
	return '';
};

// normalize, только цифры
var normalizeOnlyNumber = exports.normalizeOnlyNumber = function normalizeOnlyNumber(value) {
	if (value && value.replace) {
		return value.replace(/[^0-9]/gi, "");
	}
	return '';
};

var innHelpers = exports.innHelpers = {
	validators: {
		validInn: function validInn(_ref) {
			var value = _ref.value,
			    innTaxThirdPerson = _ref.innTaxThirdPerson,
			    innFive = _ref.innFive;

			if (isEmpty(value)) return true;

			if (innTaxThirdPerson && value === '0') {
				return true;
			}
			if (innFive && [0, 5, 10, 12].includes(value.length)) {
				return !isNaN(value.replace('.', 'q'));
			}
			if ([0, 10, 12].includes(value.length)) {
				return !isNaN(value.replace('.', 'q'));
			}
			return false;
		},
		isCorrectInn: function isCorrectInn(inn) {
			if (isEmpty(inn)) return true;

			var factor1 = [2, 4, 10, 3, 5, 9, 4, 6, 8];
			var factor2 = [7, 2, 4, 10, 3, 5, 9, 4, 6, 8];
			var factor3 = [3, 7, 2, 4, 10, 3, 5, 9, 4, 6, 8];
			var i = 0;
			var sum = 0;
			var sum2 = 0;
			var Result = false;
			var d = void 0;
			if (inn.length === 0) {
				Result = true;
			} else if (inn.length === 10) {
				// юр лицо
				sum = 0;
				for (i = 0; i <= 8; i++) {
					d = inn.slice(i, i + 1);
					sum += d * factor1[i];
				}
				sum = sum % 11;
				sum = sum % 10;
				Result = inn.slice(9, 10) == sum;
			} else if (inn.length == 12) {
				// физ лицо и ИП
				sum = 0;
				for (i = 0; i <= 9; i++) {
					d = inn.slice(i, i + 1);
					sum += d * factor2[i];
				}
				sum = sum % 11;
				sum = sum % 10;
				sum2 = 0;
				for (i = 0; i <= 10; i++) {
					d = inn.slice(i, i + 1);
					sum2 += d * factor3[i];
				}
				sum2 = sum2 % 11;
				sum2 = sum2 % 10;
				Result = inn.slice(10, 11) == sum && inn.slice(11, 12) == sum2;
			}
			return Result;
		},
		validCheck: function validCheck(_ref2) {
			var value = _ref2.value,
			    innTaxThirdPerson = _ref2.innTaxThirdPerson,
			    innFive = _ref2.innFive;

			if (isEmpty(value)) return true;

			if (innTaxThirdPerson && value === '0') {
				return true;
			}
			if (!innTaxThirdPerson && innFive && value.length === 5) {
				return true;
			}
			return innHelpers.validators.isCorrectInn(value);
		},
		validZero: function validZero(value) {
			if (isEmpty(value)) return true;

			if ([10, 12].includes(value.length)) return !/^00.*$/.test(value);
			return true;
		},
		validKoiZero: function validKoiZero(value) {
			if (isEmpty(value)) return true;

			if (value.length === 5) return !/^0+$/.test(value);
			return true;
		}
	},
	normalizer: function normalizer(value) {
		return value.replace(/[^0-9]+/g, '');
	}
};

var bankAccountStringLength = 20;
var separatePoints = [5, 8, 9, 13];

var bankAccountHelpers = exports.bankAccountHelpers = {
	validators: {
		length: function length(value) {
			var cleanValue = bankAccountHelpers.normalizers.cleanValue(value);

			if (isEmpty(cleanValue)) return true;

			return cleanValue.length === bankAccountStringLength;
		},
		controlKey: function controlKey(_ref3) {
			var value = _ref3.value,
			    bik = _ref3.bik;

			var cleanValue = bankAccountHelpers.normalizers.cleanValue(value);

			if (isEmpty(cleanValue) || isEmpty(bik)) return true;

			return cleanValue.length !== bankAccountStringLength || bankAccountHelpers.validators.checkControlKeyBankAccount(cleanValue, bik);
		},
		checkControlKeyBankAccount: function checkControlKeyBankAccount(bankAccount, bik) {
			if (!bankAccount || !bik) return false;
			var coefficient = [7, 1, 3, 7, 1, 3, 7, 1, 3, 7, 1, 3, 7, 1, 3, 7, 1, 3, 7, 1, 3, 7, 1];
			var controlNumber = bik.toString().substr(-3);
			if (controlNumber <= 2) {
				controlNumber = '0'.concat(bik.toString().substr(-5, 2));
			}
			var tempAcccount = controlNumber.concat(bankAccount);
			var sum = 0;
			for (var i = 0; i < tempAcccount.length; i++) {
				sum = sum + Number(tempAcccount.charAt(i)) * coefficient[i] % 10;
			}
			if (sum % 10 == 0) return true;
			return false;
		},
		nationalCurrency: function nationalCurrency(_ref4) {
			var value = _ref4.value,
			    currency = _ref4.currency;

			var cleanValue = bankAccountHelpers.normalizers.cleanValue(value);

			if (isEmpty(cleanValue) || isEmpty(currency)) return true;

			return cleanValue.length !== bankAccountStringLength || bankAccountHelpers.validators.isAccountNumberOfNationalCurrency(cleanValue, currency);
		},
		isAccountNumberOfNationalCurrency: function isAccountNumberOfNationalCurrency(bankAccount, currency) {
			var _nationalCurrencyAccountExpression = new RegExp('\\d{5}' + currency + '\\d{12}', 'g');
			var result = (bankAccount + '').match(_nationalCurrencyAccountExpression);
			if (!result) return false;
			return result.length > 0;
		}
	},
	normalizers: {
		parser: function parser(account) {
			var clean = bankAccountHelpers.normalizers.cleanValue(account);
			var value = bankAccountHelpers.normalizers.addSeparator(clean);
			return value;
		},
		cleanValue: function cleanValue() {
			var value = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
			var position = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : bankAccountStringLength;

			value += '';
			return value.replace(/[^0-9]+/g, '').slice(0, position);
		},
		addSeparator: function addSeparator(val) {
			if (val.length === 0) return val;
			var points = [0].concat(separatePoints, [20]);
			var number = val.substring(points[0], points[1]);
			for (var i = 1; i < points.length - 1; ++i) {
				if (val.length > points[i]) number += '.' + val.substring(points[i], points[i + 1]);
			}return number;
		}
	}
};

var paymentPurposeHelpers = exports.paymentPurposeHelpers = {
	validators: {
		ndsNone: function ndsNone(_ref5) {
			var value = _ref5.value,
			    transaction = _ref5.transaction;

			if (isEmpty(value)) return true;
			if (!transaction) return;

			var accountNdsArr = ['40101', '40302'];
			var ndsRegexp = /ндс/i;

			if (transaction.contragentBankAccountNumber && !ndsRegexp.test(value) && accountNdsArr.indexOf(transaction.contragentBankAccountNumber.toString().substr(0, 5)) < 0) {
				return false;
			}

			return true;
		},
		salary: function salary(value) {
			if (isEmpty(value)) return true;

			var paymentSalaryExp = /\s+ЗПМодульбанк\./i;

			return !paymentSalaryExp.test(' ' + value);
		}
	},
	normalizers: {
		parser: function parser(_ref6) {
			var maxLength = _ref6.maxLength,
			    externalText = _ref6.externalText;
			return function (value) {
				var externalTextLength = externalText && externalText.length && externalText.length > 0 ? externalText.length + 1 : 0;
				var clean = value.replace(/[^a-zA-Zа-яёЁА-Я0-9-+.'?:()&^%$#@№!*_{}~`\][=\\;"><|\s,//]+/g, '');
				clean = clean.replace(/[\t\f\xa0\x00\x08\x0B\x0C\x0E-\x1F]+/g, ' ');
				if (clean.length + externalTextLength > maxLength && maxLength > 0) {
					clean = clean.slice(0, maxLength - externalTextLength);
				}

				return clean;
			};
		}
	}
};

var kppHelper = exports.kppHelper = {
	validators: {
		validKpp: function validKpp() {
			var radKppTaxThirdPerson = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
			return function (value) {
				if (isEmpty(value)) {
					return true;
				}
				if (radKppTaxThirdPerson && value === '0') {
					return true;
				}
				if (value.length === 0 || value.length === 9) {
					return !isNaN(value.replace('.', 'q'));
				}

				return false;
			};
		},
		validZeroKpp: function validZeroKpp(value) {
			if (isEmpty(value)) {
				return true;
			}

			if (value.length === 9) return !/^00.*$/.test(value);

			return true;
		}
	}
};

var ogrnHelper = exports.ogrnHelper = {
	validators: {
		formatOgrn: function formatOgrn(radValidator) {
			return function (value) {
				if (isEmpty(viewValue)) {
					return true;
				}
				if (value.length === 13) {
					return radValidator.isCorrectOgrn(viewValue);
				}
				return true;
			};
		},
		formatOgrnip: function formatOgrnip(radValidator) {
			return function (value) {
				if (isEmpty(viewValue)) {
					return true;
				}
				if (value.length === 15) {
					return radValidator.isCorrectOgrn(viewValue);
				}
				return true;
			};
		}
	}
};